
libname scand 'g:\documents\AER_Macro';run;


data bed_cps_new;
   set scand.bed_cps;
   jd_cont = jd - jd_deaths;
   jr = jc + jd;
   excess = jc + jd - abs(jc-jd);
   

proc sort data=bed_cps_new;by code;run;

proc summary data=bed_cps_new;
id sec_name;
by code;
var jd jd_cont jd_deaths jr inflow escape;
output out=tab1 mean=;run;


proc print data=tab1;var code sec_name jd jd_cont jd_deaths jr inflow escape;

* Create 3 year data;

data bed_cps;
   set bed_cps_new;
qdate=year+.1*quarter;
time=qdate-1990;
time3=time/3;
tyear=ceil(time3);
if tyear=6 then tyear=5;* this puts the last year in with group 5;


proc summary data=bed_cps nway;
   class tyear code;
   var inflow escape jc jr excess jd jd_deaths jd_cont;
output out=tyear mean=;run;

*robustness checks can be done by dropping observations;

data tyear;
  set tyear;
run;

proc sort data=tyear;by tyear;run;

data scand.bed_cps_3year;
   set tyear;run;

* runnning sas versions of regressions (std errors not robust);

%macro low(lhs,rhs);

proc glm data=tyear;
    class code tyear;
model &lhs = code &rhs / solution;run;

proc glm data=tyear;
    class code tyear;
model &lhs = code / solution;run;

proc glm data=tyear;
    class code tyear;
model &lhs = code tyear &rhs / solution;run;

proc glm data=tyear;
    class code tyear;
model &lhs = code tyear / solution;run;

%mend;

%low(inflow,jd);
%low(inflow, jd_cont jd_deaths);
%low(inflow, jr);
%low(escape, jd);
%low(escape,jd_cont jd_deaths);
%low(escape, jr);


* data for scatterplot;

proc sort data=tyear;by code tyear;run;

proc standard data=tyear out=scatter_bed mean=0;by code;var inflow jd jd_cont jd_deaths
jr escape excess;run;

proc sort data=scatter_bed;by tyear;run;

proc standard data=scatter_bed out=scatter_bed mean=0;by tyear;var inflow jd jd_cont jd_deaths
jr escape excess;run;

*add back means;

proc summary data=tyear;
  var inflow jd;
output out=total mean=minflow mjd;run;

data total;
  set total;mer=1;

data scatter_bed;
  set scatter_bed;
  mer=1;

data scatter_bed;
  merge scatter_bed total;by mer;
  jd = jd + mjd;
  inflow = inflow + minflow; 


proc print data=scatter_bed;var code tyear inflow jd;run;

proc sort data=tyear;by tyear code;run;

proc glm data=tyear;
  class tyear code;
  model inflow = tyear code / solution;
output out=scatter2 residual = rinflow;
run;

proc glm data=tyear;
   class tyear code;
 model jd = tyear code / solution;
 output out=scatter3 residual = rjd;

data scatter23;
  merge scatter2 scatter3;by tyear code;mer=1;

proc print data=scatter23;var code tyear rinflow rjd;run;

data scatter23;
  merge scatter23 total;by mer;
   rjd = rjd + mjd;
  rinflow = rinflow + minflow; 

  proc print data=scatter23;var code tyear rinflow rjd;run;

proc glm data=scatter23;
  model rinflow = rjd / solution;
run;

* run regressions using scatter to within R-squared;

%macro low(lhs,rhs);

proc glm data=tyear;
  class tyear code;
  model &lhs = tyear code ;
output out=scatter2 residual = &lhs.r;
run;

proc glm data=tyear;
   class tyear code;
 model &rhs = tyear code ;
 output out=scatter3 residual = &rhs.r;

data scatter23;
  merge scatter2 scatter3;by tyear code;mer=1;

proc glm data=scatter23;
  model &lhs.r = &rhs.r / solution;
run;


%mend;

%low(inflow,jd);
%low(inflow, jr);
%low(escape, jd);
%low(escape, jr);

* now try with two RHS variables;

%macro low(lhs,rhs1,rhs2);

proc glm data=tyear;
  class tyear code;
  model &lhs = tyear code;
output out=scatter2 residual = &lhs.r;
run;

proc glm data=tyear;
   class tyear code;
 model &rhs1 = tyear code ;
 output out=scatter3 residual = &rhs1.r;
run;

proc glm data=tyear;
   class tyear code;
 model &rhs2 = tyear code ;
 output out=scatter4 residual = &rhs2.r;

data scatter234;
  merge scatter2 scatter3 scatter4;by tyear code;mer=1;
run;

proc glm data=scatter234;
  model &lhs.r = &rhs1.r &rhs2.r / solution;
run;

%mend;

%low(inflow, jd_cont, jd_deaths);
%low(escape, jd_cont, jd_deaths);



